[compiler-rt] r188541 - [ASan/RTL] Disable alloc_dealloc_mismatch by default on Windows

Timur Iskhodzhanov timurrrr at google.com
Fri Aug 16 04:04:59 PDT 2013


Author: timurrrr
Date: Fri Aug 16 06:04:59 2013
New Revision: 188541

URL: http://llvm.org/viewvc/llvm-project?rev=188541&view=rev
Log:
[ASan/RTL] Disable alloc_dealloc_mismatch by default on Windows

Modified:
    compiler-rt/trunk/lib/asan/asan_rtl.cc

Modified: compiler-rt/trunk/lib/asan/asan_rtl.cc
URL: http://llvm.org/viewvc/llvm-project/compiler-rt/trunk/lib/asan/asan_rtl.cc?rev=188541&r1=188540&r2=188541&view=diff
==============================================================================
--- compiler-rt/trunk/lib/asan/asan_rtl.cc (original)
+++ compiler-rt/trunk/lib/asan/asan_rtl.cc Fri Aug 16 06:04:59 2013
@@ -168,9 +168,9 @@ void InitializeFlags(Flags *f, const cha
   f->allow_reexec = true;
   f->print_full_thread_history = true;
   f->poison_heap = true;
-  // Turn off alloc/dealloc mismatch checker on Mac for now.
-  // TODO(glider): Fix known issues and enable this back.
-  f->alloc_dealloc_mismatch = (SANITIZER_MAC == 0);;
+  // Turn off alloc/dealloc mismatch checker on Mac and Windows for now.
+  // TODO(glider,timurrrr): Fix known issues and enable this back.
+  f->alloc_dealloc_mismatch = (SANITIZER_MAC == 0) && (SANITIZER_WINDOWS == 0);
   f->use_stack_depot = true;
   f->strict_memcmp = true;
   f->strict_init_order = false;





More information about the llvm-commits mailing list